@@ -190,7 +190,7 @@ ellipsis_info.ListRegressions <- function(objects, ..., verbose = TRUE) {
 
   # if we have nested models, check if models are provided in
   # increasing or decreasing order (according to number of DFs)
-  if (isTRUE(same_response) & is_nested) {
+  if (isTRUE(same_response) && is_nested) {
     class(objects) <- c("ListNestedRegressions", class(objects))
     attr(objects, "is_nested") <- TRUE
 
