@@ -24,37 +24,14 @@ get_call <- function(x) {
 
 #' @export
 get_call.default <- function(x) {
-  cl <- tryCatch(
-    {
-      x$call
-    },
-    error = function(x) {
-      NULL
-    }
-  )
-
-  if (is.null(cl)) {
-    cl <- tryCatch(
-      {
-        x@call
-      },
-      error = function(x) {
-        NULL
-      }
-    )
-  }
+  cl <- tryCatch(getElement(x, "call"), error = function(e) NULL)
 
   # For GAMM4
   if (is.null(cl) && "gam" %in% names(x)) {
-    cl <- tryCatch(
-      {
-        x$gam$formula # Where's the call here?
-      },
-      error = function(x) {
-        NULL
-      }
-    )
+    # Where's the call here?
+    cl <- tryCatch(x$gam$formula, error = function(e) NULL)
   }
+
   cl
 }
 
@@ -69,15 +46,25 @@ get_call.lm <- function(x) {
 #' @export
 get_call.glm <- get_call.lm
 
+#' @export
+get_call.mvord <- function(x) {
+  x$rho$mc
+}
+
 #' @export
 get_call.model_fit <- function(x) {
   get_call(x$fit)
 }
 
-
 #' @export
 get_call.lmerMod <- function(x) {
   x@call
 }
+
 #' @export
 get_call.merMod <- get_call.lmerMod
+
+#' @export
+get_call.stanreg <- function(x) {
+  x$call
+}
