@@ -2,32 +2,79 @@
 #'
 #' Create a reference matrix, useful for visualisation, with evenly spread and
 #' combined values. Usually used to make generate predictions using [get_predicted()].
-#' See this [vignette](https://easystats.github.io/modelbased/articles/visualisation_matrix.html) for a tutorial on how to create a visualisation matrix using this function.
+#' See this [vignette](https://easystats.github.io/modelbased/articles/visualisation_matrix.html)
+#' for a tutorial on how to create a visualisation matrix using this function.
 #'
 #' @param x An object from which to construct the reference grid.
-#' @param at Can be `"all"`, a character vector or list of named elements, indicating
-#'   the predictors of interest (focal predictors). Can also contain assignments
-#'   (as named list, e.g. `at = list(c(Sepal.Length = c(2, 4), Species = "setosa"))`,
-#'   or as string, e.g. `at = "Sepal.Length = 2"` or
+#' @param at Indicate at which values _focal predictors_ (variables) should be
+#'   represented. If not specified otherwise, representative values for numeric
+#'   variables or predictors are evenly distributed from the minimum to the maximum,
+#'   with a total number of `length` values covering that range (see 'Examples').
+#'   Possible options for `at` are:
+#'   - `"all"`, which will include all variables or predictors.
+#'   - a character vector of one or more variable or predictor names, like
+#'   `c("Species", "Sepal.Width")`, which will create a grid of all combinations
+#'   of unique values. For factors, will use all levels, for numeric variables,
+#'   will use a range of length `length` (evenly spread from minimum to maximum)
+#'   and for character vectors, will use all values.
+#'   - a list of named elements, indicating focal predictors and their representative
+#'   values, e.g. `at = list(c(Sepal.Length = c(2, 4), Species = "setosa"))`.
+#'   - a string with assignments, e.g. `at = "Sepal.Length = 2"` or
 #'   `at = c("Sepal.Length = 2", "Species = 'setosa'")` - note the usage of single
-#'   and double quotes to assign strings within strings). The remaining variables
-#'   will be fixed.
+#'   and double quotes to assign strings within strings.
+#'
+#'   There is a special handling of assignments with _brackets_, i.e. values
+#'   defined inside `[` and `]`.For **numeric** variables, the value(s) inside
+#'   the brackets should either be
+#'   - two values, indicating minum and maximung (e.g. `at = "Sepal.Length = [0, 5]`),
+#'   for which a range of length `length` (evenly spread from given minimum to
+#'   maximum) is created.
+#'   - more than two numeric values `at = "Sepal.Length = [2,3,4,5]"`, in which
+#'   case these values are used as representative values.
+#'   - a "token" that creates pre-defined representative values:
+#'     - for mean and -/+ 1 SD around the mean: `"x = [sd]"`
+#'     - for median and -/+ 1 MAD around the median: `"x = [mad]"`
+#'     - for Tukey's five number summary (minimum, lower-hinge, median, upper-hinge, maximum): `"x = [fivenum]"`
+#'     - for terciles, including minimum and maximum: `"x = [terciles]"`
+#'     - for terciles, excluding minimum and maximum: `"x = [terciles2]"`
+#'     - for quartiles, including minimum and maximum: `"x = [quartiles]"`
+#'     - for quartiles, excluding minimum and maximum: `"x = [quartiles2]"`
+#'     - for minimum and maximum value: `"x = [minmax]"`
+#'     - for 0 and the maximum value: `"x = [zeromax]"`
+#'
+#'   For **factors** variables, the value(s) inside the brackets should indicate
+#'   one or more factor levels, like `at = "Species = [setosa, versicolor]"`.
+#'   **Note**: the `length` argument will be ignored when using brackets-tokens.
+#'
+#'   The remaining variables not specified in `at` will be fixed (see also arguments
+#'   `factors` and `numerics`).
 #' @param length Length of numeric target variables selected in `"at"`. This arguments
 #'   controls the number of (equally spread) values that will be taken to represent the
 #'   continuous variables. A longer length will increase precision, but can also
 #'   substantially increase the size of the datagrid (especially in case of interactions).
 #'   If `NA`, will return all the unique values. In case of multiple continuous target
 #'   variables, `length` can also be a vector of different values (see examples).
-#' @param range If `"range"` (default), will use the minimum and maximum of the
-#'   original data vector as end-points (min and max). If an interval type is specified,
-#'   such as [`"iqr"`][IQR()], [`"ci"`][bayestestR::ci()], [`"hdi"`][bayestestR::hdi()] or [`"eti"`][bayestestR::eti()], it will spread the values within
-#'   that range (the default CI width is `95%` but this can be changed by adding for instance
-#'   `ci = 0.90`. See [IQR()] and [bayestestR::ci()]. This can be useful to have
-#'   more robust change and skipping extreme values. If [`"sd"`][sd()] or [`"mad"`][mad()], it will
-#'   spread by this dispersion index around the mean or the median, respectively.
-#'   If the `length` argument is an even number (e.g., `4`), it will have one more
-#'   step on the positive side (i.e., `-1, 0, +1, +2`). The result is a named vector.
-#'   See examples.
+#' @param range Option to control the representative values given in `at`, if
+#'   no specific values were provided. `range` can be one of the following:
+#'   - `"range"` (default), will use the minimum and maximum of the original data
+#'   vector as end-points (min and max).
+#'   - if an interval type is specified, such as [`"iqr"`][IQR()],
+#'   [`"ci"`][bayestestR::ci()], [`"hdi"`][bayestestR::hdi()] or
+#'   [`"eti"`][bayestestR::eti()], it will spread the values within that range
+#'   (the default CI width is `95%` but this can be changed by adding for instance
+#'   `ci = 0.90`.) See [IQR()] and [bayestestR::ci()]. This can be useful to have
+#'   more robust change and skipping extreme values.
+#'   - if [`"sd"`][sd()] or [`"mad"`][mad()], it will spread by this dispersion
+#'   index around the mean or the median, respectively. If the `length` argument
+#'   is an even number (e.g., `4`), it will have one more step on the positive
+#'   side (i.e., `-1, 0, +1, +2`). The result is a named vector. See 'Examples.'
+#'   - `"grid"` will create a reference grid that is useful when plotting
+#'   predictions, by choosing representative values for numeric variables based
+#'   on their position in the reference grid. If a numeric variable is the first
+#'   predictor in `at`, values from minimum to maximum of the same length as
+#'   indicated in `length` are generated. For numeric predictors not specified at
+#'   first in `at`, mean and -1/+1 SD around the mean are returned. For factors,
+#'   all levels are returned.
 #' @param factors Type of summary for factors. Can be `"reference"` (set at the
 #'   reference level), `"mode"` (set at the most common level) or `"all"` to
 #'   keep all levels.
@@ -55,6 +102,7 @@
 #'   variable should be included in the data grid or not.
 #' @param data Optional, the data frame that was used to fit the model. Usually,
 #'   the data is retrieved via `get_data()`.
+#' @param verbose Toggle warnings.
 #' @param ... Arguments passed to or from other methods (for instance, `length`
 #'   or `range` to control the spread of numeric variables.).
 #'
@@ -79,16 +127,23 @@
 #'   ) # change non-targets fixing
 #'   get_datagrid(iris, at = "Sepal.Length", range = "ci", ci = 0.90) # change min/max of target
 #'   get_datagrid(iris, at = "Sepal.Length = [0, 1]") # Manually change min/max
+#'   get_datagrid(iris, at = "Sepal.Length = [sd]") # -1 SD, mean and +1 SD
+#'   get_datagrid(iris, at = "Sepal.Length = [quartiles]") # quartiles
+#'
+#'   # Numeric and categorical variables, generating a grid for plots
+#'   # default spread length = 10
+#'   get_datagrid(iris, at = c("Sepal.Length", "Species"), range = "grid")
+#'   # default spread length = 3 (-1 SD, mean and +1 SD)
+#'   get_datagrid(iris, at = c("Species", "Sepal.Length"), range = "grid")
 #'
 #'
 #'   # Standardization and unstandardization
 #'   data <- get_datagrid(iris, at = "Sepal.Length", range = "sd", length = 3)
 #'   data$Sepal.Length # It is a named vector (extract names with `names(out$Sepal.Length)`)
-#'   # TODO: uncomment when datawizard > 0.3.1 is out
-#'   # datawizard::standardize(data, select = "Sepal.Length")
-#'   # data <- get_datagrid(iris, at = "Sepal.Length = c(-2, 0, 2)") # Manually specify values
-#'   # data
-#'   # datawizard::unstandardize(data, select = "Sepal.Length")
+#'   datawizard::standardize(data, select = "Sepal.Length")
+#'   data <- get_datagrid(iris, at = "Sepal.Length = c(-2, 0, 2)") # Manually specify values
+#'   data
+#'   datawizard::unstandardize(data, select = "Sepal.Length")
 #'
 #'
 #'   # Multiple variables are of interest, creating a combination --------------
@@ -109,6 +164,7 @@
 #' model <- lm(Sepal.Length ~ Sepal.Width * Petal.Length, data = iris)
 #' # Get datagrid of predictors
 #' data <- get_datagrid(model, length = c(20, 3), range = c("range", "sd"))
+#' # same as: get_datagrid(model, range = "grid", length = 20)
 #' # Add predictions
 #' data$Sepal.Length <- get_predicted(model, data = data)
 #' # Visualize relationships (each color is at -1 SD, Mean, and + 1 SD of Petal.Length)
@@ -148,7 +204,8 @@ get_datagrid.data.frame <- function(x,
     # check for interactions in "at"
     at <- .extract_at_interactions(at)
 
-    # Valid at argument
+    # Validate at argument ============================
+
     if (all(at == "all")) {
       at <- colnames(x)
     }
@@ -177,7 +234,7 @@ get_datagrid.data.frame <- function(x,
       }
     })
 
-    # Deal with targets ==========================================================
+    # Deal with targets =======================================================
 
     if (is.character(at)) {
       # Find eventual user-defined specifications for each target
@@ -190,7 +247,10 @@ get_datagrid.data.frame <- function(x,
       # Create target list of factors -----------------------------------------
       facs <- list()
       for (fac in specs[specs$is_factor == TRUE, "varname"]) {
-        facs[[fac]] <- get_datagrid(x[[fac]], at = specs[specs$varname == fac, "expression"])
+        facs[[fac]] <- get_datagrid(
+          x[[fac]],
+          at = specs[specs$varname == fac, "expression"]
+        )
       }
 
       # Create target list of numerics ----------------------------------------
@@ -201,14 +261,19 @@ get_datagrid.data.frame <- function(x,
         if (length(length) == 1) {
           length <- rep(length, length(numvars))
         } else if (length(length) != length(numvars)) {
-          stop(format_message("The number of elements in `length` must match the number of numeric target variables (n = ", length(numvars), ")."), call. = FALSE)
+          stop(format_message(
+            "The number of elements in `length` must match the number of numeric target variables (n = ", length(numvars), ")."
+          ), call. = FALSE)
         }
         # Sanitize 'range' argument
         if (length(range) == 1) {
           range <- rep(range, length(numvars))
         } else if (length(range) != length(numvars)) {
-          stop(format_message("The number of elements in `range` must match the number of numeric target variables (n = ", length(numvars), ")."), call. = FALSE)
+          stop(format_message(
+            "The number of elements in `range` must match the number of numeric target variables (n = ", length(numvars), ")."
+          ), call. = FALSE)
         }
+
         # Get datagrids
         for (i in seq_along(numvars)) {
           num <- numvars[i]
@@ -217,6 +282,7 @@ get_datagrid.data.frame <- function(x,
             reference = reference[[num]],
             length = length[i],
             range = range[i],
+            is_first_predictor = specs$varname[1] == num,
             ...
           )
         }
@@ -232,11 +298,14 @@ get_datagrid.data.frame <- function(x,
     # numeric variables, the other one factors.
     targets <- expand.grid(c(nums, facs))
 
+    # sort targets data frame according to order specified in "at"
+    targets <- tryCatch(targets[specs$varname], error = function(e) targets)
+
     # Preserve range ---------------------------------------------------------
     if (preserve_range == TRUE && length(facs) > 0 && length(nums) > 0) {
       # Loop through the combinations of factors
       facs_combinations <- expand.grid(facs)
-      for (i in 1:nrow(facs_combinations)) {
+      for (i in seq_len(nrow(facs_combinations))) {
         # Query subset of original dataset
         subset <- x[.data_match(x, to = facs_combinations[i, , drop = FALSE]), , drop = FALSE]
         idx <- .data_match(targets, to = facs_combinations[i, , drop = FALSE])
@@ -278,6 +347,8 @@ get_datagrid.data.frame <- function(x,
     } else {
       targets <- merge(targets, rest_df, sort = FALSE)
     }
+  } else {
+    rest_vars <- NA
   }
 
   # Prepare output =============================================================
@@ -293,7 +364,7 @@ get_datagrid.data.frame <- function(x,
   }
 
   # Attributes
-  attr(targets, "adjusted_for") <- ifelse(length(rest_vars) >= 1, rest_vars, NA)
+  attr(targets, "adjusted_for") <- rest_vars
   attr(targets, "at_specs") <- specs
   attr(targets, "at") <- at
   attr(targets, "preserve_range") <- preserve_range
@@ -302,8 +373,12 @@ get_datagrid.data.frame <- function(x,
 
   # Printing decorations
   attr(targets, "table_title") <- c("Visualisation Grid", "blue")
-  if (length(rest_vars) >= 1) attr(targets, "table_footer") <- paste0("\nMaintained constant: ", paste0(rest_vars, collapse = ", "))
-  if (!is.null(attr(targets, "table_footer"))) attr(targets, "table_footer") <- c(attr(targets, "table_footer"), "blue")
+  if (!(length(rest_vars) == 1 && is.na(rest_vars)) && length(rest_vars) >= 1) {
+    attr(targets, "table_footer") <- paste0("\nMaintained constant: ", paste0(rest_vars, collapse = ", "))
+  }
+  if (!is.null(attr(targets, "table_footer"))) {
+    attr(targets, "table_footer") <- c(attr(targets, "table_footer"), "blue")
+  }
 
   class(targets) <- unique(c("datagrid", "visualisation_matrix", class(targets)))
   targets
@@ -354,6 +429,14 @@ get_datagrid.data.frame <- function(x,
           "Please report the bug at https://github.com/easystats/insight/issues"
         )), call. = FALSE)
       }
+      # see "get_modelmatrix()" and #626. Reference level is currently
+      # a character vector, which causes the error
+      # > Error in `contrasts<-`(`*tmp*`, value = contr.funs[1 + isOF[nn]]) :
+      # > contrasts can be applied only to factors with 2 or more levels
+      # this is usually avoided by calling ".pad_modelmatrix()", but this
+      # function ignores character vectors. so we need to make sure that this
+      # factor level is also of class factor.
+      out <- factor(out)
     }
   }
   out
@@ -378,7 +461,8 @@ get_datagrid.numeric <- function(x, length = 10, range = "range", ...) {
   # Check and clean the target argument
   specs <- .get_datagrid_clean_target(x, ...)
 
-  # If an expression is detected, run it and return it
+  # If an expression is detected, run it and return it - we don't need
+  # to create any spread of values to cover the range; spread is user-defined
   if (!is.na(specs$expression)) {
     return(eval(parse(text = specs$expression)))
   }
@@ -390,7 +474,7 @@ get_datagrid.numeric <- function(x, length = 10, range = "range", ...) {
 
   # Sanity check
   if (!is.numeric(length)) {
-    stop("`length` argument should be an number.")
+    stop("`length` argument should be an number.", call. = FALSE)
   }
 
   # Create a spread
@@ -404,17 +488,26 @@ get_datagrid.double <- get_datagrid.numeric
 
 #' @keywords internal
 .create_spread <- function(x, length = 10, range = "range", ci = 0.95, ...) {
-  range <- match.arg(tolower(range), c("range", "iqr", "ci", "hdi", "eti", "sd", "mad"))
+  range <- match.arg(tolower(range), c("range", "iqr", "ci", "hdi", "eti", "sd", "mad", "grid"))
 
   # bayestestR only for some options
   if (range %in% c("ci", "hdi", "eti")) {
     check_if_installed("bayestestR")
   }
 
+  # check if range = "grid" - then use mean/sd for every numeric that
+  # is not first predictor...
+  if (range == "grid") {
+    range <- "sd"
+    if (isFALSE(list(...)$is_first_predictor)) {
+      length <- 3
+    }
+  }
+
   # If Range is a dispersion (e.g., SD or MAD)
   if (range %in% c("sd", "mad")) {
     spread <- -floor((length - 1) / 2):ceiling((length - 1) / 2)
-    if (range %in% c("sd")) {
+    if (range == "sd") {
       disp <- stats::sd(x, na.rm = TRUE)
       center <- mean(x, na.rm = TRUE)
       labs <- ifelse(sign(spread) == -1, paste(spread, "SD"),
@@ -503,9 +596,9 @@ get_datagrid.logical <- get_datagrid.character
     }
 
     # If there is an equal sign
-    if (grepl("length.out =", at)) {
+    if (grepl("length.out =", at, fixed = TRUE)) {
       expression <- at # This is an edgecase
-    } else if (grepl("=", at)) {
+    } else if (grepl("=", at, fixed = TRUE)) {
       parts <- trim_ws(unlist(strsplit(at, "=", fixed = TRUE))) # Split and clean
       varname <- parts[1] # left-hand part is probably the name of the variable
       at <- parts[2] # right-hand part is the real target
@@ -515,7 +608,9 @@ get_datagrid.logical <- get_datagrid.character
       if (!is.na(varname)) {
         x <- x[[varname]]
       } else {
-        stop(format_message("Couldn't find which variable were selected in `at`. Check spelling and specification."), call. = FALSE)
+        stop(format_message(
+          "Couldn't find which variable were selected in `at`. Check spelling and specification."
+        ), call. = FALSE)
       }
     }
 
@@ -541,15 +636,47 @@ get_datagrid.logical <- get_datagrid.character
         expression <- paste0("as.factor(c(", paste0(parts, collapse = ", "), "))")
       } else {
         # Numeric
-        # If only two, it's probably the range
-        if (length(parts) == 2) {
+        # If one, might be a shortcut
+        if (length(parts) == 1) {
+          shortcuts <- c("meansd", "sd", "mad", "quartiles", "quartiles2", "zeromax", "minmax", "terciles", "terciles2", "fivenum")
+          if (parts %in% shortcuts) {
+            if (parts %in% c("meansd", "sd")) {
+              center <- mean(x, na.rm = TRUE)
+              spread <- stats::sd(x, na.rm = TRUE)
+              expression <- paste0("c(", center - spread, ",", center, ",", center + spread, ")")
+            } else if (parts == "mad") {
+              center <- stats::median(x, na.rm = TRUE)
+              spread <- stats::mad(x, na.rm = TRUE)
+              expression <- paste0("c(", center - spread, ",", center, ",", center + spread, ")")
+            } else if (parts == "quartiles") {
+              expression <- paste0("c(", paste0(as.vector(stats::quantile(x, na.rm = TRUE)), collapse = ","), ")")
+            } else if (parts == "quartiles2") {
+              expression <- paste0("c(", paste0(as.vector(stats::quantile(x, na.rm = TRUE))[2:4], collapse = ","), ")")
+            } else if (parts == "terciles") {
+              expression <- paste0("c(", paste0(as.vector(stats::quantile(x, probs = (1:2) / 3, na.rm = TRUE)), collapse = ","), ")")
+            } else if (parts == "terciles2") {
+              expression <- paste0("c(", paste0(as.vector(stats::quantile(x, probs = (0:3) / 3, na.rm = TRUE)), collapse = ","), ")")
+            } else if (parts == "fivenum") {
+              expression <- paste0("c(", paste0(as.vector(stats::fivenum(x, na.rm = TRUE)), collapse = ","), ")")
+            } else if (parts == "zeromax") {
+              expression <- paste0("c(0,", max(x, na.rm = TRUE), ")")
+            } else if (parts == "minmax") {
+              expression <- paste0("c(", min(x, na.rm = TRUE), ",", max(x, na.rm = TRUE), ")")
+            }
+          } else if (is.numeric(parts)) {
+            expression <- parts
+          } else {
+            stop(format_message(
+              paste0("The `at` argument (", at, ") should either indicate the minimum and the maximum, or one of the following options: ", paste0(shortcuts, collapse = ", ", "."))
+            ), call. = FALSE)
+          }
+          # If only two, it's probably the range
+        } else if (length(parts) == 2) {
           expression <- paste0("seq(", parts[1], ", ", parts[2], ", length.out = length)")
           # If more, it's probably the vector
         } else if (length(parts) > 2) {
           parts <- as.numeric(parts)
           expression <- paste0("c(", paste0(parts, collapse = ", "), ")")
-        } else {
-          stop(format_message(paste0("The `at` argument (", at, ") should indicate the minimum and the maximum.")), call. = FALSE)
         }
       }
       # Else, try to directly eval the content
@@ -564,7 +691,9 @@ get_datagrid.logical <- get_datagrid.character
           eval(parse(text = at))
         },
         error = function(r) {
-          stop(format_message(paste0("The `at` argument (`", original_target, "`) cannot be read and could be mispecified.")), call. = FALSE)
+          stop(format_message(
+            paste0("The `at` argument (`", original_target, "`) cannot be read and could be mispecified.")
+          ), call. = FALSE)
         }
       )
     }
@@ -591,6 +720,7 @@ get_datagrid.default <- function(x,
                                  include_random = FALSE,
                                  include_response = FALSE,
                                  data = NULL,
+                                 verbose = TRUE,
                                  ...) {
   # sanity check
   if (!is_model(x)) {
@@ -600,9 +730,21 @@ get_datagrid.default <- function(x,
   # Retrieve data from model
   data <- .get_model_data_for_grid(x, data)
 
-  # Deal with intercept-only models
+  # save response - might be necessary to include
   response <- find_response(x)
-  if (include_response == FALSE) {
+
+  # check some exceptions here: logistic regression models with factor response
+  # usually require the response to be included in the model, else `get_modelmatrix()`
+  # fails, which is required to compute SE/CI for `get_predicted()`
+  minfo <- model_info(x)
+  if (minfo$is_binomial && minfo$is_logit && is.factor(data[[response]]) && !include_response && verbose) {
+    warning(format_message(
+      "Logistic regression model has a categorical response variable. You may need to set `include_response=TRUE` to make it work for predictions."
+    ), call. = FALSE)
+  }
+
+  # Deal with intercept-only models
+  if (isFALSE(include_response)) {
     data <- data[!colnames(data) %in% response]
     if (ncol(data) < 1) {
       stop(format_message("Model only seems to be an intercept-only model. Use `include_response=TRUE` to create the reference grid."), call. = FALSE)
@@ -625,7 +767,10 @@ get_datagrid.default <- function(x,
     }
   }
 
+  # user wants to include all predictors?
   if (all(at == "all")) at <- colnames(data)
+
+  # exluce smooth terms?
   if (isFALSE(include_smooth) || identical(include_smooth, "fixed")) {
     s <- find_smooth(x, flatten = TRUE)
     if (!is.null(s)) {
@@ -730,7 +875,7 @@ get_datagrid.datagrid <- get_datagrid.visualisation_matrix
   if (!is.data.frame(to)) {
     to <- as.data.frame(to)
   }
-  idx <- 1:nrow(x)
+  idx <- seq_len(nrow(x))
   for (col in names(to)) {
     if (col %in% names(x)) {
       idx <- idx[x[[col]][idx] %in% to[[col]]]
@@ -752,12 +897,27 @@ get_datagrid.datagrid <- get_datagrid.visualisation_matrix
     data <- tryCatch(get_data(x)[find_terms(x, "all", flatten = TRUE)], error = function(e) NULL)
   }
 
+  # brute force - use all!
+  if (is.null(data)) {
+    cols <- unique(
+      find_terms(x, "all", flatten = TRUE),
+      find_variables(x, "all", flatten = TRUE)
+    )
+    data <- tryCatch(
+      {
+        d <- get_data(x)
+        d[intersect(colnames(d), cols)]
+      },
+      error = function(e) NULL
+    )
+  }
+
   # still found no data - stop here
   if (is.null(data)) {
     stop(format_message(
       "Can't access data that was used to fit the model in order to create the reference grid.",
       "Please use the `data` argument."
-    ))
+    ), call. = FALSE)
   }
 
   data
@@ -766,7 +926,8 @@ get_datagrid.datagrid <- get_datagrid.visualisation_matrix
 
 
 .extract_at_interactions <- function(at) {
-  interaction_terms <- grepl("(:|\\*)", at)
+  # get interaction terms, but only if these are not inside brackets (like "[4:8]")
+  interaction_terms <- grepl("(:|\\*)(?![^\\[]*\\])", at, perl = TRUE)
   if (any(interaction_terms)) {
     at <- unique(clean_names(trim_ws(compact_character(c(
       at[!interaction_terms],
