@@ -173,6 +173,19 @@ get_df.lqm <- get_df.lqmm
 
 #' @export
 get_df.cgam <- function(x, type = "residual", ...) {
+  type <- match.arg(tolower(type), choices = c("residual", "model"))
+  if (type == "model") {
+    .model_df(x)
+  } else {
+    # x$resid_df_obs
+    # new in cgam 1.18
+    stats::df.residual(x)
+  }
+}
+
+
+#' @export
+get_df.cgamm <- function(x, type = "residual", ...) {
   type <- match.arg(tolower(type), choices = c("residual", "model"))
   if (type == "model") {
     .model_df(x)
@@ -315,7 +328,7 @@ get_df.lmerMod <- function(x, type = "residual", ...) {
     check_if_installed("lmerTest")
     type <- tools::toTitleCase(type) # lmerTest wants title case
     if (!inherits(dots$data, "data.frame")) {
-      stop("The `data` argument should be a data.frame.")
+      stop("The `data` argument should be a data.frame.", call. = FALSE)
     }
     mm <- get_modelmatrix(x, data = dots$data)
     out <- sapply(
@@ -453,7 +466,7 @@ get_df.systemfit <- function(x, type = "residual", ...) {
   f <- find_formula(x)
   system_names <- names(f)
 
-  for (i in 1:length(system_names)) {
+  for (i in seq_along(system_names)) {
     dfs <- rep(s[[i]]$df[2], length(params[[i]]))
     df_names <- rep(names(params[i]), length(params[[i]]))
     df <- c(df, stats::setNames(dfs, df_names))
