@@ -15,12 +15,17 @@ get_modelmatrix <- function(x, ...) {
   UseMethod("get_modelmatrix")
 }
 
-
 #' @export
-get_modelmatrix.default <- function(x, ...) {
-  stats::model.matrix(object = x, ...)
+get_modelmatrix.default <- function(x, data = NULL, ...) {
+  if (is.null(data)) {
+    mm <- stats::model.matrix(object = x, ...)
+  } else {
+    mm <- .pad_modelmatrix_unpad(x, data, ...)
+  }
+  mm
 }
 
+
 #' @export
 get_modelmatrix.merMod <- function(x, ...) {
   dots <- list(...)
@@ -209,8 +214,11 @@ get_modelmatrix.BFBayesFactor <- function(x, ...) {
   BayesFactor::model.matrix(x, ...)
 }
 
+
+
 # helper ----------------
 
+
 .data_in_dots <- function(..., object = NULL, default_data = NULL) {
   dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
   data_arg <- if ("data" %in% names(dot.arguments)) {
@@ -221,3 +229,41 @@ get_modelmatrix.BFBayesFactor <- function(x, ...) {
   remaining_dots <- setdiff(names(dot.arguments), "data")
   do.call(stats::model.matrix, c(list(object = object, data = data_arg), remaining_dots))
 }
+
+
+.pad_modelmatrix_unpad <- function(x, data, ...) {
+  data <- .pad_modelmatrix(x = x, data = data)
+  mm <- stats::model.matrix(object = x, data = data, ...)
+  .unpad_modelmatrix(mm = mm, data = data)
+}
+
+
+.pad_modelmatrix <- function(x, data, min_levels = 2) {
+  # return original data if there are already enough factors
+  fac <- lapply(Filter(is.factor, data), unique)
+  fac_len <- sapply(fac, length)
+  if (all(fac_len > min_levels)) {
+    out <- data
+    attr(out, "pad") <- 0
+    return(out)
+  }
+
+  # factors from data in model object
+  modeldata <- get_data(x)
+  fac <- lapply(Filter(is.factor, modeldata), function(i) unique(i)[1:min_levels])
+  pad <- lapply(seq_len(min_levels), function(...) utils::head(data, n = 1))
+  pad <- do.call("rbind", pad)
+  for (n in names(fac)) {
+    pad[[n]] <- fac[[n]]
+  }
+
+  out <- rbind(pad, data)
+  attr(out, "pad") <- nrow(pad)
+  return(out)
+}
+
+
+.unpad_modelmatrix <- function(mm, data) {
+  npad <- attr(data, "pad")
+  mm[(npad + 1):nrow(mm), , drop = FALSE]
+}
