@@ -38,7 +38,7 @@
   if (length(predict) > 1) {
     predict <- predict[1]
     if (isTRUE(verbose)) {
-      msg <- format_message(sprintf("More than one option provided in `predict`. Using first option '%s' now."), predict[1])
+      msg <- format_message(sprintf("More than one option provided in `predict`. Using first option `%s` now."), predict[1])
       warning(msg, call. = FALSE)
     }
   }
@@ -56,22 +56,27 @@
 
 
   # Intermediate step, check data classes  ------
+  # if data=NULL, check terms
+  # if data!=NULL, check data
   ############################################################################
 
-  tryCatch(
-    {
-      data_classes <- attributes(stats::terms(x))$dataClasses
-      if (any(grepl("matrix", data_classes, fixed = TRUE)) && isTRUE(verbose)) {
-        message(format_message(
-          "Some of the variables were in matrix-format - probably you used 'scale()' on your data?",
-          "If so, and you get an error, please try 'datawizard::standardize()' to standardize your data."
-        ))
-      }
-    },
-    error = function(e) {
-
-    }
-  )
+  if (is.null(data)) {
+    flag_matrix <- tryCatch(
+      any(grepl("matrix", attributes(stats::terms(x))$dataClasses, fixed = TRUE)),
+      error = function(e) FALSE
+    )
+  } else {
+    flag_matrix <- tryCatch(
+      any(sapply(data, function(x) inherits(x, "matrix"))),
+      error = function(e) FALSE
+    )
+  }
+  if (isTRUE(flag_matrix) && isTRUE(verbose)) {
+    message(format_message(
+      "Some of the variables were in matrix-format - probably you used `scale()` on your data?",
+      "If so, and you get an error, please try `datawizard::standardize()` to standardize your data."
+    ))
+  }
 
 
   # Second step, evaluate "predict" argument                      ------------
@@ -118,7 +123,7 @@
   # model-supported predicted type
   if (isTRUE(verbose) && !is.null(predict) && !predict %in% supported) {
     msg <- format_message(
-      sprintf('`predict` = "%s"` is not officially supported by `get_predicted()`.', predict),
+      sprintf("`predict` = \"%s\"` is not officially supported by `get_predicted()`.", predict),
       "`predict` will be passed directly to the `predict()` method for the model and not validated.",
       "Please check the validity and scale of the results.",
       "Set `verbose = FALSE` to silence this warning, or use one of the supported values for the `predict` argument:",
@@ -264,7 +269,7 @@
     if (!all(re_terms %in% names(data))) {
       if (isTRUE(verbose) && isTRUE(include_random)) {
         warning(format_message(
-          "`include_random` was set to `TRUE`, but not all random effects were found in 'data'.",
+          "`include_random` was set to `TRUE`, but not all random effects were found in `data`.",
           "Setting `include_random = FALSE` now."
         ), call. = FALSE)
       }
@@ -284,7 +289,7 @@
       if (!all(all_levels_found)) {
         if (isTRUE(verbose) && isTRUE(include_random)) {
           warning(format_message(
-            "`include_random` was set to `TRUE`, but grouping factor(s) in 'data' has new levels not in the original data.",
+            "`include_random` was set to `TRUE`, but grouping factor(s) in `data` has new levels not in the original data.",
             "Either use `allow.new.levels=TRUE`, or make sure to include only valid values for grouping factor(s).",
             "Setting `include_random = FALSE` now."
           ), call. = FALSE)
