@@ -8,7 +8,7 @@ get_predicted.stanreg <- function(x,
                                   data = NULL,
                                   predict = "expectation",
                                   iterations = NULL,
-                                  ci = 0.95,
+                                  ci = NULL,
                                   ci_method = NULL,
                                   include_random = "default",
                                   include_smooth = TRUE,
