@@ -82,10 +82,12 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 
 # special handling ---------------
 
+
 .get_sigma.model_fit <- function(x, verbose = TRUE, ...) {
   .get_sigma(x$fit, verbose = verbose)
 }
 
+
 .get_sigma.lrm <- function(x, verbose = TRUE, ...) {
   s <- stats::sigma(x)
   s <- s[length(s)]
@@ -93,6 +95,7 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
   s
 }
 
+
 .get_sigma.VGAM <- function(x, verbose = TRUE, ...) {
   s <- tryCatch(
     exp(stats::coef(x)[["(Intercept):2"]]),
@@ -102,6 +105,7 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
   s
 }
 
+
 .get_sigma.merModList <- function(x, verbose = TRUE, ...) {
   s <- suppressWarnings(summary(x))
   s <- s$residError
@@ -109,18 +113,40 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
   s
 }
 
+
 .get_sigma.summary.lm <- function(x, verbose = TRUE, ...) {
   s <- x$sigma
   class(s) <- c("insight_aux", class(s))
   s
 }
 
+
 .get_sigma.selection <- function(x, verbose = TRUE, ...) {
   s <- unname(stats::coef(x)["sigma"])
   class(s) <- c("insight_aux", class(s))
   s
 }
 
+
+.get_sigma.cgam <- function(x, verbose = TRUE, ...) {
+  s <- tryCatch(
+    {
+      sqrt(get_deviance(x, verbose = verbose) / get_df(x, type = "residual", verbose = verbose))
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+
+  if (is_empty_object(s)) {
+    return(NULL)
+  }
+
+  class(s) <- c("insight_aux", class(s))
+  s
+}
+
+
 .get_sigma.cpglmm <- function(x, verbose = TRUE, ...) {
   s <- tryCatch(
     {
@@ -136,6 +162,7 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
   s
 }
 
+
 .get_sigma.brmsfit <- function(x, verbose = TRUE, ...) {
   s <- tryCatch(
     {
