@@ -16,7 +16,8 @@
 #' transform the response variable; `$inverse`, the inverse-function of
 #' `$transformation` (can be used for "back-transformation"). If no
 #' transformation was applied, both list-elements `$transformation` and
-#' `$inverse` just return `function(x) x`.
+#' `$inverse` just return `function(x) x`. If transformation is unknown,
+#' `NULL` is returned.
 #'
 #' @examples
 #' # identity, no transformation
@@ -38,16 +39,27 @@
 get_transformation <- function(x) {
   transform_fun <- find_transformation(x)
 
+  # unknown
+  if (is.null(transform_fun)) {
+    return(NULL)
+  }
+
   if (transform_fun == "identity") {
     out <- list(transformation = function(x) x, inverse = function(x) x)
   } else if (transform_fun == "log") {
     out <- list(transformation = log, inverse = exp)
   } else if (transform_fun %in% c("log1p", "log(x+1)")) {
     out <- list(transformation = log1p, inverse = expm1)
+  } else if (transform_fun == "log10") {
+    out <- list(transformation = log10, inverse = function(x) NA)
+  } else if (transform_fun == "log2") {
+    out <- list(transformation = log2, inverse = function(x) NA)
   } else if (transform_fun == "exp") {
     out <- list(transformation = exp, inverse = log)
   } else if (transform_fun == "sqrt") {
     out <- list(transformation = sqrt, inverse = function(x) x^2)
+  } else if (transform_fun == "power") {
+    out <- list(transformation = function(x) x^2, inverse = sqrt)
   } else if (transform_fun == "expm1") {
     out <- list(transformation = expm1, inverse = log1p)
   } else if (transform_fun == "log-log") {
