@@ -139,6 +139,6 @@ get_weights.list <- function(x, na_rm = FALSE, null_as_ones = FALSE, ...) {
   if ("gam" %in% names(x)) {
     get_weights(x$gam, na_rm = na_rm, null_as_ones = null_as_ones, ...)
   } else {
-    stop("Cannot find weights in this object. Please an open an issue!")
+    stop("Cannot find weights in this object. Please an open an issue!", call. = FALSE)
   }
 }
