@@ -148,7 +148,7 @@ n_obs.gamm <- function(x, ...) {
   if (object_has_names(x, "gam")) {
     n_obs(x$gam, ...)
   } else {
-    stop("Cannot find n_obs for this object. Please an open an issue!")
+    stop("Cannot find n_obs for this object. Please an open an issue!", call. = FALSE)
   }
 }
 
