@@ -1,8 +1,8 @@
 .runThisTest <- Sys.getenv("RunAllinsightTests") == "yes"
 
 if (.runThisTest) {
-  if (require("testthat") &&
-    require("insight") && require("glmmTMB") && require("biglm")) {
+  if (requiet("testthat") &&
+    requiet("insight") && requiet("glmmTMB") && requiet("biglm")) {
     data(Salamanders)
     Salamanders$cover <- abs(Salamanders$cover)
 
@@ -37,6 +37,10 @@ if (.runThisTest) {
       expect_warning(get_random(m1))
     })
 
+    test_that("get_varcov", {
+      expect_equal(vcov(m1), get_varcov(m1), tolerance = 1e-3)
+    })
+
     test_that("find_response", {
       expect_identical(find_response(m1), "count")
     })
