@@ -1,12 +1,9 @@
-if (require("testthat") &&
-  require("insight") &&
-  require("censReg") &&
-  require("AER")) {
+if (requiet("testthat") && requiet("insight") && requiet("censReg") && requiet("AER")) {
   data("Affairs", package = "AER")
-  m1 <-
-    censReg(affairs ~ age + yearsmarried + religiousness + occupation + rating,
-      data = Affairs
-    )
+  m1 <- censReg(
+    affairs ~ age + yearsmarried + religiousness + occupation + rating,
+    data = Affairs
+  )
 
   test_that("model_info", {
     expect_false(model_info(m1)$is_linear)
@@ -44,6 +41,10 @@ if (require("testthat") &&
     expect_warning(get_random(m1))
   })
 
+  test_that("get_varcov", {
+    expect_equal(vcov(m1), get_varcov(m1), tolerance = 1e-3)
+  })
+
   test_that("find_response", {
     expect_identical(find_response(m1), "affairs")
   })
