@@ -1,8 +1,10 @@
 requiet("mhurdle")
 data("Interview", package = "mhurdle")
 m1 <- mhurdle(shows ~ 0 | linc + smsa + age + educ + size, data = Interview, h2 = TRUE, dist = "n", method = "bhhh")
-m2 <- mhurdle(shows ~ educ + size | linc | smsa + age, data = Interview,
-    h2 = FALSE, method = "bhhh", corr = TRUE, finalHessian = TRUE)
+m2 <- mhurdle(shows ~ educ + size | linc | smsa + age,
+  data = Interview,
+  h2 = FALSE, method = "bhhh", corr = TRUE, finalHessian = TRUE
+)
 
 test_that("get_data", {
   d1 <- get_data(m1)
